@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2012-2014, Robin Hahling
+ * Copyright (c) 2012-2017, Robin Hahling
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -37,26 +37,17 @@
  * header file for dfc.c
  */
 
-#include "display.h"
 #include "dotfile.h"
-#include "export.h"
 #include "extern.h"
 #include "list.h"
 #include "util.h"
+#include "export/display.h"
+#include "export/export.h"
+#include "platform/services.h"
 
 /* function declaration */
 void usage(int status);
-void fetch_info(struct list *lst);
-void disp(struct list *lst, char *fsfilter, char *fsnfilter, struct display *sdisp);
-
-#if defined(__FreeBSD__) || defined(__OpenBSD__) || defined(__APPLE__) \
-	|| defined(__DragonFly__)
-/* avoid struct statfs declared inside parameter list warning */
-struct statfs;
-char * statfs_flags_to_str(struct statfs *s);
-#elif defined(__NetBSD__)
-struct statvfs;
-char *statfs_flags_to_str(struct statvfs *s);
-#endif /* __FreeBSD__ || __OpenBSD__ || __APPLE__ || __DragonFly__ || __NetBSD__ */
+void disp(struct list *lst, const char *fsfilter, const char *fsnfilter,
+    struct display *sdisp);
 
 #endif /* ndef DFC_H */
