@@ -186,7 +186,6 @@ set_conf(const char *key, const char *val)
 {
 	int tmp;
 	int ret = 0;
-	char *tmpc = NULL;
 
 	if (strcmp(key, "bold_font") == 0) {
 		if ((tmp = get_boolean_value(val)) == -1)
@@ -265,78 +264,50 @@ set_conf(const char *key, const char *val)
 			ret = -1;
 		}
 	} else if (strcmp(key, "html_color_header_bg") == 0) {
-		if (chk_html_colorcode(val) == 0) {
-			if (!(tmpc = strdup(val)))
-				goto strdup_failed;
-			else
-				cnf.hcheadbg = tmpc;
-		} else
+		if (chk_html_colorcode(val) != 0)
 			goto non_valid_html_color;
+		if (snprintf(cnf.hcheadbg, sizeof(cnf.hcheadbg), "%s", val) != HEXCOLOR_LEN)
+			goto assignment_failed;
 	} else if (strcmp(key, "html_color_header_fg") == 0) {
-		if (chk_html_colorcode(val) == 0) {
-			if (!(tmpc = strdup(val)))
-				goto strdup_failed;
-			else
-				cnf.hcheadfg = tmpc;
-		} else
+		if (chk_html_colorcode(val) != 0)
 			goto non_valid_html_color;
+		if (snprintf(cnf.hcheadfg, sizeof(cnf.hcheadfg), "%s", val) != HEXCOLOR_LEN)
+			goto assignment_failed;
 	} else if (strcmp(key, "html_color_cell_bg") == 0) {
-		if (chk_html_colorcode(val) == 0) {
-			if (!(tmpc = strdup(val)))
-				goto strdup_failed;
-			else
-				cnf.hccellbg = tmpc;
-		} else
+		if (chk_html_colorcode(val) != 0)
 			goto non_valid_html_color;
+		if (snprintf(cnf.hccellbg, sizeof(cnf.hccellbg), "%s", val) != HEXCOLOR_LEN)
+			goto assignment_failed;
 	} else if (strcmp(key, "html_color_cell_fg") == 0) {
-		if (chk_html_colorcode(val) == 0) {
-			if (!(tmpc = strdup(val)))
-				goto strdup_failed;
-			else
-				cnf.hccellfg = tmpc;
-		} else
+		if (chk_html_colorcode(val) != 0)
 			goto non_valid_html_color;
+		if (snprintf(cnf.hccellfg, sizeof(cnf.hccellfg), "%s", val) != HEXCOLOR_LEN)
+			goto assignment_failed;
 	} else if (strcmp(key, "html_color_hover_bg") == 0) {
-		if (chk_html_colorcode(val) == 0) {
-			if (!(tmpc = strdup(val)))
-				goto strdup_failed;
-			else
-				cnf.hchoverbg = tmpc;
-		} else
+		if (chk_html_colorcode(val) != 0)
 			goto non_valid_html_color;
+		if (snprintf(cnf.hchoverbg, sizeof(cnf.hchoverbg), "%s", val) != HEXCOLOR_LEN)
+			goto assignment_failed;
 	} else if (strcmp(key, "html_color_hover_fg") == 0) {
-		if (chk_html_colorcode(val) == 0) {
-			if (!(tmpc = strdup(val)))
-				goto strdup_failed;
-			else
-				cnf.hchoverfg = tmpc;
-		} else
+		if (chk_html_colorcode(val) != 0)
 			goto non_valid_html_color;
+		if (snprintf(cnf.hchoverfg, sizeof(cnf.hchoverfg), "%s", val) != HEXCOLOR_LEN)
+			goto assignment_failed;
 	} else if (strcmp(key, "html_color_low") == 0) {
-		if (chk_html_colorcode(val) == 0) {
-			if (!(tmpc = strdup(val)))
-				goto strdup_failed;
-			else
-				cnf.hclow = tmpc;
-		} else
+		if (chk_html_colorcode(val) != 0)
 			goto non_valid_html_color;
+		if (snprintf(cnf.hclow, sizeof(cnf.hclow), "%s", val) != HEXCOLOR_LEN)
+			goto assignment_failed;
 	} else if (strcmp(key, "html_color_medium") == 0) {
-		if (chk_html_colorcode(val) == 0) {
-			if (!(tmpc = strdup(val)))
-				goto strdup_failed;
-			else
-				cnf.hcmedium = tmpc;
-		} else
+		if (chk_html_colorcode(val) != 0)
 			goto non_valid_html_color;
-
+		if (snprintf(cnf.hcmedium, sizeof(cnf.hcmedium), "%s", val) != HEXCOLOR_LEN)
+			goto assignment_failed;
 	} else if (strcmp(key, "html_color_high") == 0) {
-		if (chk_html_colorcode(val) == 0) {
-			if (!(tmpc = strdup(val)))
-				goto strdup_failed;
-			else
-				cnf.hchigh = tmpc;
-		} else
+		if (chk_html_colorcode(val) != 0)
 			goto non_valid_html_color;
+		if (snprintf(cnf.hchigh, sizeof(cnf.hchigh), "%s", val) != HEXCOLOR_LEN)
+			goto assignment_failed;
 	} else if (strcmp(key, "csv_separator") == 0) {
 		if (strlen(val) == 1)
 			cnf.csvsep = val[0];
@@ -351,33 +322,27 @@ set_conf(const char *key, const char *val)
 		ret = -1;
 	}
 
-	free(tmpc);
 	return ret;
 
 unknown_boolean_value:
-	(void)fprintf(stderr, _("Unknown boolean value: %s\n"), val);
-	free(tmpc);
+	(void)fprintf(stderr, _("Unknown boolean value for '%s': %s\n"), key, val);
 	return -1;
 
 unknown_color_value:
-	(void)fprintf(stderr, _("Unknown color value: %s\n"), val);
-	free(tmpc);
+	(void)fprintf(stderr, _("Unknown color value for '%s': %s\n"), key, val);
 	return -1;
 
 non_valid_html_color:
-	(void)fprintf(stderr, _("Not a valid HTML color: %s\n"), val);
-	free(tmpc);
+	(void)fprintf(stderr, _("Not a valid HTML color for '%s': %s\n"), key, val);
 	return -1;
 
-strdup_failed:
-	(void)fprintf(stderr, _("Could not assign value from configuration "
-			"file: %s\n"), val);
-	free(tmpc);
+assignment_failed:
+	(void)fprintf(stderr, _("Cannot assign value for '%s': %s\n"), key, val);
 	return -1;
 }
 
-/*
- * init a conf structure
+/**
+ * Init a conf structure with default valuues.
  * @cnf: structure to be initiated
  */
 void
@@ -393,15 +358,15 @@ init_conf(struct conf *config)
 
 	config->gsymbol	= '=';
 
-	config->hcheadbg	= "970000";
-	config->hcheadfg	= "FFFFFF";
-	config->hccellbg	= "E9E9E9";
-	config->hccellfg	= "000000";
-	config->hchoverbg	= "FFFFFF";
-	config->hchoverfg	= "000000";
-	config->hclow		= "348017";
-	config->hcmedium	= "FDD017";
-	config->hchigh		= "F62217";
+	(void)snprintf(config->hcheadbg, sizeof(config->hcheadbg), "%s", "970000");
+	(void)snprintf(config->hcheadfg, sizeof(config->hcheadfg), "%s", "FFFFFF");
+	(void)snprintf(config->hccellbg, sizeof(config->hccellbg), "%s", "E9E9E9");
+	(void)snprintf(config->hccellfg, sizeof(config->hccellfg), "%s", "000000");
+	(void)snprintf(config->hchoverbg, sizeof(config->hchoverbg), "%s", "FFFFFF");
+	(void)snprintf(config->hchoverfg, sizeof(config->hchoverfg), "%s", "000000");
+	(void)snprintf(config->hclow, sizeof(config->hclow), "%s", "348017");
+	(void)snprintf(config->hcmedium, sizeof(config->hcmedium), "%s", "FDD017");
+	(void)snprintf(config->hchigh, sizeof(config->hchigh), "%s", "F62217");
 
 	config->csvsep = ',';
 }
