@@ -261,6 +261,7 @@ print_unit(int i, int mode)
 		default:
 			(void)fputs("Could not print unit type in"
 					" human-readable format\n", stderr);
+			return;
 		}
 	case 'b':
 		if (mode)
@@ -731,29 +732,29 @@ colortostr(int color)
 int
 colortoint(const char *col)
 {
-	if (strcoll(col, "black") == 0)
+	if (strcmp(col, "black") == 0)
 		return BLACK;
-	else if (strcoll(col, "red") == 0)
+	else if (strcmp(col, "red") == 0)
 		return RED;
-	else if (strcoll(col, "green") == 0)
+	else if (strcmp(col, "green") == 0)
 		return GREEN;
-	else if (strcoll(col, "yellow") == 0)
+	else if (strcmp(col, "yellow") == 0)
 		return YELLOW;
-	else if (strcoll(col, "blue") == 0)
+	else if (strcmp(col, "blue") == 0)
 		return BLUE;
-	else if (strcoll(col, "magenta") == 0)
+	else if (strcmp(col, "magenta") == 0)
 		return MAGENTA;
-	else if (strcoll(col, "cyan") == 0)
+	else if (strcmp(col, "cyan") == 0)
 		return CYAN;
-	else if (strcoll(col, "white") == 0)
+	else if (strcmp(col, "white") == 0)
 		return WHITE;
 	else
 		return -1;
 }
 
 /*
- * check if the input string is a valid html color code.
- * ie: it should be an hexadecimal value
+ * Check if the input string is a valid hexadecimal color code.
+ * ie: it should be a HEXCOLOR_LEN long hexadecimal value.
  * Returns 0 if all went well, otherwise it returns -1
  * @color: input color
  * NOTE: color should omit the #: white is FFFFFF and not #FFFFFF
@@ -763,10 +764,10 @@ chk_html_colorcode(const char *color)
 {
 	int i;
 
-	if (strlen(color) != HTMLCOLORCODELENGTH)
+	if (strlen(color) != HEXCOLOR_LEN)
 		return -1;
 
-	for (i = 0; i < HTMLCOLORCODELENGTH; i++)
+	for (i = 0; i < HEXCOLOR_LEN; i++)
 		if (isxdigit(color[i]) == 0)
 			return -1;
 
