@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2012-2014, Robin Hahling
+ * Copyright (c) 2012-2017, Robin Hahling
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -40,27 +40,30 @@
 
 #include "extern.h"
 #include "list.h"
+#include "platform/services.h"
 
 /* function declaration */
 int imax(int a, int b);
 char * strtrim(char *str);
 char * shortenstr(char *str, int len);
 char * sanitizestr(const char *str);
-int getttywidth(void);
 int humanize(double *n);
 int humanize_i(uint64_t *n);
 void print_unit(int i, int mode);
 double cvrt(double n);
-int fstypefilter(char *type, char *filter, int nm);
-int fsnamefilter(char *fsname, char *filter, int nm);
-int is_remote(char *fstype);
+int fsfilter(const char *fs, const char *filter, int nm);
 int cmp(struct fsmntinfo *a, struct fsmntinfo *b);
 struct fsmntinfo * msort(struct fsmntinfo *fmi);
-void auto_adjust(struct list lst, int width);
-int req_width(struct list lst);
+int getttywidth(void);
+void init_maxwidths(void);
+int get_req_width(double fs_size);
+void update_maxwidth(struct fsmntinfo *fmi);
+void auto_adjust(int tty_width);
 char * fetchdate(void);
-char * colortostr(int color);
-int colortoint(char *col);
-int chk_html_colorcode(char *color);
+const char * colortostr(int color);
+int colortoint(const char *col);
+int chk_html_colorcode(const char *color);
+int is_pseudofs(const char *type);
+int is_remotefs(const char *type);
 
 #endif /* ndef UTIL_H */
